/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "CartesianAcceleration.h"

#include <math.h>

#include <boost/math/quaternion.hpp>

using namespace std;
using namespace nemo;
using namespace rsc::math;

namespace rci {

TranslationalAcceleration::TranslationalAcceleration() :
        CartesianTranslational() {
}

TranslationalAcceleration::~TranslationalAcceleration() {
}

TranslationalAcceleration::TranslationalAcceleration(double valx, double valy,
        double valz) :
        CartesianTranslational(valx, valy, valz) {
}

TranslationalAcceleration::TranslationalAcceleration(nemo::RealVector values) :
        CartesianTranslational(values) {
}

TranslationalAccelerationPtr TranslationalAcceleration::fromM_s2(double x,
        double y, double z) {
    return TranslationalAccelerationPtr(new TranslationalAcceleration(x, y, z));
}

double TranslationalAcceleration::m_s2(unsigned int index) {
    return this->asDouble(index);
}

nemo::RealVector TranslationalAcceleration::m_s2Vector() {
    return this->asDoubleVector();
}

std::string TranslationalAcceleration::print() const {
    ostringstream outstream(ostringstream::out);
    outstream.precision(3); // Precision when printing double values
    outstream << "TranslationalAcceleration<x=" << this->asDouble(0) << ",y="
            << this->asDouble(1) << ",z=" << this->asDouble(2) << ">(m/s^2)";
    return outstream.str();
}

}
