/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>

#include "rci/dto/CartesianValues.h"

namespace rci {

/**
 * Domain object, representing a cartesian force and rotatory stiffness in all
 * three dimensions. The default unit is newton per meter (\f$N/m\f$).
 * @ingroup DTO
 * @ingroup Compliance
 */
class TranslationalDamping: public CartesianTranslational {

public:
    TranslationalDamping();
    TranslationalDamping(double x, double y, double z);
    TranslationalDamping(nemo::RealVector values);
    TranslationalDamping(const TranslationalDamping& damping);
};

/**
 * Domain object, representing an orientation or rotational transformation in
 * cartesian space. The default unit is newton-metres per radian
 * (\f$N*m/rad\f$).
 * @ingroup DTO
 * @ingroup Compliance
 */
class RotationalDamping: public CartesianRotational {

public:
    RotationalDamping();
    RotationalDamping(double vala, double valb, double valc, double vald);
    RotationalDamping(nemo::RealVector values);
    RotationalDamping(const RotationalDamping& damping);
};

/**
 * Domain object, representing a full cartesian pose, consisting of
 * translational transformation and orientation.
 * @ingroup DTO
 * @ingroup Compliance
 */
class CartesianDamping: public CartesianValue {

public:
    CartesianDamping();
    CartesianDamping(double valx, double valy, double valz, double vala,
            double valb, double valc, double vald);
    CartesianDamping(nemo::RealVector values);
    CartesianDamping(const CartesianDamping& damping);
};

}
