/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>
#include <boost/shared_ptr.hpp>

#include "rci/dto/CartesianValues.h"

namespace rci {

class Forces;
typedef boost::shared_ptr<Forces> ForcesPtr;

/**
 * Domain object, representing a cartesian force and torques in all three
 * dimensions. Default units are (N, N, N).
 * @ingroup DTO
 */
class Forces: public CartesianTranslational {

public:
    Forces();
    Forces(double x, double y, double z);
    Forces(nemo::RealVector values);
    Forces(const Forces& forces);
};

/**
 * Domain object, representing an orientation or rotational transformation in
 * cartesian space.
 * Default units are (N*m, N*m, N*m, N*m).
 * @ingroup DTO
 */
class Torques: public CartesianRotational {

public:
    Torques();
    Torques(double vala, double valb, double valc, double vald);
    Torques(nemo::RealVector values);
    Torques(const Torques& torques);
};

/**
 * Domain object, representing a full cartesian wrench, consisting of
 * translational forces and torques.
 * Default units are (N, N, N, N*m, N*m, N*m, N*m).
 * @ingroup DTO
 */
class Wrench: public CartesianValue {

public:
    Wrench();
    Wrench(double valx, double valy, double valz, double vala,
            double valb, double valc, double vald);
    Wrench(nemo::RealVector values);
    Wrench(const Wrench& wrench);
};

}
