/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "CartesianImpedance.h"

using namespace nemo;

namespace rci {

TranslationalImpedance::TranslationalImpedance() :
        CartesianTranslational() {
}

TranslationalImpedance::TranslationalImpedance(double valx, double valy,
        double valz) :
        CartesianTranslational(valx, valy, valz) {
}

TranslationalImpedance::TranslationalImpedance(
        const TranslationalImpedance& impedance) :
        CartesianTranslational() {
    this->_values = RealVector(dim(3));
    this->_values[0] = impedance.asDouble(0);
    this->_values[1] = impedance.asDouble(1);
    this->_values[2] = impedance.asDouble(2);
}

TranslationalImpedance::TranslationalImpedance(nemo::RealVector values) :
        CartesianTranslational(values) {
}

RotationalImpedance::RotationalImpedance() :
        CartesianRotational() {
}

RotationalImpedance::RotationalImpedance(double vala, double valb, double valc,
        double vald) :
        CartesianRotational(vala, valb, valc, vald) {
}

RotationalImpedance::RotationalImpedance(nemo::RealVector values) :
        CartesianRotational(values) {
}

RotationalImpedance::RotationalImpedance(const RotationalImpedance& impedance) :
        CartesianRotational() {
    this->_values = RealVector(impedance.asDouble(0), impedance.asDouble(1),
            impedance.asDouble(2));
}

CartesianImpedance::CartesianImpedance() :
        CartesianValue() {
}

CartesianImpedance::CartesianImpedance(double valx, double valy, double valz,
        double vala, double valb, double valc, double vald) :
        CartesianValue(valx, valy, valz, vala, valb, valc, vald) {
}

CartesianImpedance::CartesianImpedance(const CartesianImpedance& impedance) :
        CartesianValue(impedance) {
}

CartesianImpedance::CartesianImpedance(nemo::RealVector values) :
        CartesianValue(values) {
    this->_transl = TranslationalImpedance(values[0], values[1], values[2]);
    this->_rot = RotationalImpedance(values[3], values[4], values[5],
            values[6]);
}

}
