/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>

#include "rci/dto/CartesianValues.h"

namespace rci {

/**
 * Compliance bla
 * @defgroup Compliance Compliance
 */

/**
 * Domain object, representing a cartesian force and RotationalImpedance in all three
 * dimensions. Default units are (N, N, N, N*cm, N*cm, N*cm).
 *
 * @ingroup DTO
 * @ingroup Compliance
 */
class TranslationalImpedance: public CartesianTranslational {

public:
    TranslationalImpedance();
    TranslationalImpedance(double x, double y, double z);
    TranslationalImpedance(nemo::RealVector values);
    TranslationalImpedance(const TranslationalImpedance& impedance);
};

/**
 * Domain object, representing an orientation or rotational transformation in
 * cartesian space.
 *
 * @ingroup DTO
 * @ingroup Compliance
 */
class RotationalImpedance: public CartesianRotational {

public:
    RotationalImpedance();
    RotationalImpedance(double vala, double valb, double valc, double vald);
    RotationalImpedance(nemo::RealVector values);
    RotationalImpedance(const RotationalImpedance& impedance);
};

/**
 * Domain object, representing a full cartesian pose, consisting of
 * translational transformation and orientation.
 * @ingroup DTO
 * @ingroup Compliance
 */
class CartesianImpedance: public CartesianValue {

public:
    CartesianImpedance();
    CartesianImpedance(double valx, double valy, double valz, double vala,
            double valb, double valc, double vald);
    CartesianImpedance(nemo::RealVector values);
    CartesianImpedance(const CartesianImpedance& impedance);
};

}
