/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>
#include <sstream>
#include <math.h>

#include <boost/shared_ptr.hpp>

// RSC
#include <rsc/math/MathUtils.h>

#include <cca/dto/DataTransferObject.h>
#include "cca/dto/ContainingDoubles.h"

namespace rci {

class Length;
typedef boost::shared_ptr<Length> LengthPtr;

/**
 * Domain object, representing length values.
 * Default representatin is in meter (m), according to the International
 * System of Units (SI).
 * @ingroup DTO
 */
class Length: public cca::DataTransferObject, public cca::ContainingDoubles {

public:
    Length();
    Length(nemo::RealVector values);

    /**
     * Returns length in meters.
     *
     * @param index
     * 			Index of the value to return
     * @return Length in meter
     */
    virtual double m(unsigned int index) const;

    /**
     * Create JointAngles from a JointAngles object (deep copy)
     *
     * @param JointAngles object
     */
    static LengthPtr copy(const Length& length);

protected:
    /**
     * Print function
     */
    virtual std::string print() const;
};

}
