/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "Pressure.h"

using namespace std;
using namespace nemo;
using namespace cca;

namespace rci {

Pressure::Pressure() :
    DataTransferObject(), ContainingDoubles() {
}

Pressure::Pressure(RealVector values) :
    DataTransferObject(), ContainingDoubles(values) {
}

PressurePtr Pressure::copy(const Pressure& pressure) {
	return PressurePtr(new Pressure(pressure));
}

double Pressure::Pa(unsigned int index) const {
	return this->asDouble(index);
}

std::string Pressure::print() const {
    ostringstream outstream(ostringstream::out);
    outstream.precision(3); // Precision when printing double values
    outstream << "Pressure<";
    for (unsigned int i = 0; i < this->getDimension(); ++i) {
        if (i > 0) {
            outstream << ",";
        }
        outstream << this->asDouble(i);
    }
    outstream << ">(Pa)" << std::endl;
    return outstream.str();
}

}
