/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>
#include <sstream>
#include <math.h>
#include <boost/shared_ptr.hpp>

#include <cca/dto/DataTransferObject.h>
#include "cca/dto/ContainingDoubles.h"

namespace rci {

class Pressure;
typedef boost::shared_ptr<Pressure> PressurePtr;

/**
 * Domain object, representing pressure values.
 * Default representatin is in pascal (Pa), according to the International
 * System of Units (SI).
 * @ingroup DTO
 */
class Pressure: public cca::DataTransferObject, public cca::ContainingDoubles {

public:
    Pressure();
    Pressure(nemo::RealVector values);

    /**
     * Returns pressure in pascal.
     *
     * @param index
     * 			Index of the value to return
     * @return Pressure in pascal
     */
    virtual double Pa(unsigned int index) const;

    /**
     * Create Pressure from a Pressure object (deep copy)
     *
     * @param Pressure object
     */
    static PressurePtr copy(const Pressure& pressure);

protected:
    /**
     * Print function
     */
    virtual std::string print() const;
};

}
