#include <gtest/gtest.h>

#include <iostream>
#include <vector>
#include <boost/shared_ptr.hpp>

#include "rci/dto/CartesianPose.h"

using namespace nemo;
using namespace rci;

class TranslationTest: public ::testing::Test {
protected:

    TranslationTest() :
            values(), translation() {
        values = RealVector(dim(3));
        values[0] = 1.12;
        values[1] = 2.0;
        values[2] = -1.1;
        translation = Translation(values);
    }

    virtual ~TranslationTest() {
    }

    RealVector values;
    Translation translation;
};

TEST_F(TranslationTest, testInitialization)
{
    EXPECT_EQ(3, Translation().getDimension());
}

TEST_F(TranslationTest, testConstruction)
{
    // Check dimension
    Translation t = Translation(values);
    EXPECT_EQ(3, t.getDimension());

    // Check dimension
    t = Translation(1, 2, 3);
    EXPECT_EQ(3, t.getDimension());
}

TEST_F(TranslationTest, testValueGetter)
{
    RealVector testvalues;

    // Check example values
    EXPECT_DOUBLE_EQ(1.12, translation.asDouble(0));
    EXPECT_DOUBLE_EQ(2.0, translation.asDouble(1));
    EXPECT_DOUBLE_EQ(-1.1, translation.asDouble(2));

    // Check values vector
    testvalues = translation.asDoubleVector();
    EXPECT_DOUBLE_EQ(values[0], testvalues[0]);
    EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
    EXPECT_DOUBLE_EQ(values[2], testvalues[2]);
}

TEST_F(TranslationTest, testCartesianGetter)
{
    // Check position values
    EXPECT_DOUBLE_EQ(1.12, translation.x());
    EXPECT_DOUBLE_EQ(2.0, translation.y());
    EXPECT_DOUBLE_EQ(-1.1, translation.z());
}
