#include <gtest/gtest.h>

#include <iostream>
#include <vector>
#include <boost/shared_ptr.hpp>

#include "rci/dto/CartesianValues.h"

using namespace rci;
using namespace nemo;

class CartesianValuesTest: public ::testing::Test {
protected:

    CartesianValuesTest() :
            values(), cv() {
        values = RealVector(dim(7));
        values[0] = 1.12;
        values[1] = 2.0;
        values[2] = -1.1;
        values[3] = 1.0;
        values[4] = 132234.0;
        values[5] = 0.0;
        values[6] = 1.0;
        cv = CartesianValue(values);
    }

    virtual ~CartesianValuesTest() {
    }

    RealVector values;
    CartesianValue cv;
};

TEST_F(CartesianValuesTest, testInitialization)
{
    EXPECT_EQ(7, CartesianValue().getDimension());
}

TEST_F(CartesianValuesTest, testConstruction)
{
    // Check dimension
    CartesianValue c = CartesianValue(values);
    EXPECT_EQ(7, c.getDimension());

    // Check dimension
    c = CartesianValue(1, 2, 3, 4, 5, 6, 7);
    EXPECT_EQ(7, c.getDimension());
}

TEST_F(CartesianValuesTest, testValueGetter)
{
    RealVector testvalues;

    // Check example values
    EXPECT_DOUBLE_EQ(1.12, cv.asDouble(0));
    EXPECT_DOUBLE_EQ(-1.1, cv.asDouble(2));
    EXPECT_DOUBLE_EQ(132234.0, cv.asDouble(4));

    // Check values vector
    testvalues = cv.asDoubleVector();
    EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
    EXPECT_DOUBLE_EQ(values[3], testvalues[3]);
    EXPECT_DOUBLE_EQ(values[5], testvalues[5]);
}

TEST_F(CartesianValuesTest, testCartesianGetter)
{
    // Check position values
    EXPECT_DOUBLE_EQ(1.12, cv.x());
    EXPECT_DOUBLE_EQ(2.0, cv.y());
    EXPECT_DOUBLE_EQ(-1.1, cv.z());

    // Check orientation values
    EXPECT_DOUBLE_EQ(1.00, cv.q0());
    EXPECT_DOUBLE_EQ(132234.0, cv.q1());
    EXPECT_DOUBLE_EQ(0.0, cv.q2());
    EXPECT_DOUBLE_EQ(1.0, cv.q3());
}
