#include <gtest/gtest.h>

#include <iostream>
#include <math.h>
#include <boost/shared_ptr.hpp>

#include "rci/dto/Doubles.h"

using namespace nemo;
using namespace std;
using namespace rci;

class DoublesTest: public ::testing::Test {
protected:

	DoublesTest() :
			values(), ja() {
		values = RealVector(dim(3));
		values[0] = 1.2 * M_PI;
		values[1] = -3 * M_PI;
		values[2] = -2 * M_PI;
		ja = Doubles(values);
	}

	virtual ~DoublesTest() {
	}

	RealVector values;
	Doubles ja;
};

TEST_F(DoublesTest, isEmptyInitially) {
	EXPECT_EQ(0, Doubles().getDimension());
}

TEST_F(DoublesTest, testConstruction) {
	// Check dimension
	Doubles j = Doubles(values);
	EXPECT_EQ(3, j.getDimension());
}

TEST_F(DoublesTest, testConstructionFromSingleDouble) {
	// Check dimension
	Doubles j = Doubles(1.234);

	EXPECT_EQ(1, j.getDimension());
	EXPECT_DOUBLE_EQ(1.234, j.asDouble(0));
}

TEST_F(DoublesTest, testCopyContructor) {
	Doubles cp(ja);
	EXPECT_DOUBLE_EQ(ja.asDouble(0), cp.asDouble(0));
	EXPECT_DOUBLE_EQ(ja.asDouble(1), cp.asDouble(1));
	EXPECT_DOUBLE_EQ(ja.asDouble(2), cp.asDouble(2));
}

TEST_F(DoublesTest, testStaticCopyCreation) {
	DoublesPtr jaPtr = Doubles::copy(ja);

	EXPECT_EQ(ja.getDimension(), jaPtr->getDimension());
	EXPECT_DOUBLE_EQ(ja.asDouble(0), jaPtr->asDouble(0));
	EXPECT_DOUBLE_EQ(ja.asDouble(1), jaPtr->asDouble(1));
	EXPECT_DOUBLE_EQ(ja.asDouble(2), jaPtr->asDouble(2));
}

TEST_F(DoublesTest, testPointerCopy) {
	DoublesPtr jaPtr = DoublesPtr(new Doubles(values));
	DoublesPtr ptrCpy = jaPtr;

	EXPECT_EQ(jaPtr->getDimension(), ptrCpy->getDimension());
	EXPECT_DOUBLE_EQ(jaPtr->asDouble(0), ptrCpy->asDouble(0));
	EXPECT_DOUBLE_EQ(jaPtr->asDouble(1), ptrCpy->asDouble(1));
	EXPECT_DOUBLE_EQ(jaPtr->asDouble(2), ptrCpy->asDouble(2));
}

TEST_F(DoublesTest, testGetters) {
	RealVector testvalues;

	// Check example values
	EXPECT_DOUBLE_EQ(1.2 * M_PI, ja.asDouble(0));
	EXPECT_DOUBLE_EQ(-3 * M_PI, ja.asDouble(1));
	EXPECT_DOUBLE_EQ(-2 * M_PI, ja.asDouble(2));

	// Check values vector
	testvalues = ja.asDoubleVector();
	EXPECT_DOUBLE_EQ(values[0], testvalues[0]);
	EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
	EXPECT_DOUBLE_EQ(values[2], testvalues[2]);
}

TEST_F(DoublesTest, testSetters) {
	RealVector degrees(dim(3)), radians(dim(3));

	radians[0] = 0;
	radians[1] = -M_PI / 2;
	radians[2] = 3 * M_PI / 2;

	degrees[0] = 0;
	degrees[1] = -90;
	degrees[2] = 270;

	DoublesPtr wrongSize = Doubles::create(2, 2.0);

	// test dimension mismatch exception
	EXPECT_THROW(wrongSize->setValues(degrees), std::runtime_error);
	EXPECT_THROW(wrongSize->setValue(2, 180.0), std::runtime_error);
}
