#include <gtest/gtest.h>

#include <iostream>
#include <boost/shared_ptr.hpp>

#include "rci/dto/JointValues.h"

using namespace nemo;
using namespace rci;

class JointValuesTest: public ::testing::Test {
protected:

    JointValuesTest() :
            values(), jv() {
        values = RealVector(dim(3));
        values[0] = 1.12;
        values[1] = 2.0;
        values[2] = -1.1;
        jv = JointValues(values);
    }

    virtual ~JointValuesTest() {
    }

    RealVector values;
    JointValues jv;
};

TEST_F(JointValuesTest, isEmptyInitially)
{
    EXPECT_EQ(0, JointValues().getDimension());
}

TEST_F(JointValuesTest, testConstruction)
{
    // Check dimension
    JointValues j = JointValues(values);
    unsigned int fu = j.getDimension();
    EXPECT_EQ(3, fu);
}

TEST_F(JointValuesTest, testValues)
{
    RealVector testvalues;

    // Check example values
    EXPECT_DOUBLE_EQ(1.12, jv.asDouble(0));
    EXPECT_DOUBLE_EQ(2.0, jv.asDouble(1));
    EXPECT_DOUBLE_EQ(-1.1, jv.asDouble(2));

    // Check values vector
    testvalues = jv.asDoubleVector();
    EXPECT_DOUBLE_EQ(values[0], testvalues[0]);
    EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
    EXPECT_DOUBLE_EQ(values[2], testvalues[2]);
}

