#include <gtest/gtest.h>

#include <iostream>
#include <math.h>
#include <boost/shared_ptr.hpp>

#include "rci/dto/JointVelocities.h"
//#include "rci/dto/converter/JointVelocitiesConverter.h"

using namespace nemo;
using namespace std;
using namespace rci;

class JointVelocitiesTest: public ::testing::Test {
protected:

    JointVelocitiesTest() :
            values(), ja() {
        values = RealVector(dim(3));
        values[0] = 1.2 * M_PI;
        values[1] = -3 * M_PI;
        values[2] = -2 * M_PI;
        ja = JointVelocities(values);
    }

    virtual ~JointVelocitiesTest() {
    }

    RealVector values;
    JointVelocities ja;
};

TEST_F(JointVelocitiesTest, isEmptyInitially)
{
    EXPECT_EQ(0, JointVelocities().getDimension());
}

TEST_F(JointVelocitiesTest, testConstruction)
{
    // Check dimension
    JointVelocities j = JointVelocities(values);
    EXPECT_EQ(3, j.getDimension());
}

TEST_F(JointVelocitiesTest, testGetters)
{
    RealVector testvalues;

    // Check example values
    EXPECT_DOUBLE_EQ(1.2 * M_PI, ja.asDouble(0));
    EXPECT_DOUBLE_EQ(-3 * M_PI, ja.asDouble(1));
    EXPECT_DOUBLE_EQ(-2 * M_PI, ja.asDouble(2));

    // Check values vector
    testvalues = ja.asDoubleVector();
    EXPECT_DOUBLE_EQ(values[0], testvalues[0]);
    EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
    EXPECT_DOUBLE_EQ(values[2], testvalues[2]);
}
